@@ -26,6 +26,7 @@ class HTMLRewriterMixin(object):
             'applet':  {'codebase': 'oe_',
                         'archive': 'oe_'},
             'area':    {'href': defmod},
+            'audio':   {'src': 'oe_'},
             'base':    {'href': defmod},
             'blockquote': {'cite': defmod},
             'body':    {'background': 'im_'},
@@ -33,7 +34,8 @@ class HTMLRewriterMixin(object):
             'embed':   {'src': 'oe_'},
             'head':    {'': defmod},  # for head rewriting
             'iframe':  {'src': 'if_'},
-            'img':     {'src': 'im_'},
+            'img':     {'src': 'im_',
+                        'srcset': 'im_'},
             'ins':     {'cite': defmod},
             'input':   {'src': 'im_'},
             'form':    {'action': defmod},
@@ -42,10 +44,13 @@ class HTMLRewriterMixin(object):
             'meta':    {'content': defmod},
             'object':  {'codebase': 'oe_',
                         'data': 'oe_'},
+            'param':   {'value': 'oe_'},
             'q':       {'cite': defmod},
             'ref':     {'href': 'oe_'},
             'script':  {'src': 'js_'},
             'source':  {'src': 'oe_'},
+            'video':   {'src': 'oe_'},
+
             'div':     {'data-src': defmod,
                         'data-uri': defmod},
             'li':      {'data-src': defmod,
@@ -120,6 +125,11 @@ class HTMLRewriterMixin(object):
         else:
             return None
 
+    def _rewrite_srcset(self, value, mod=''):
+        values = value.split(',')
+        values = map(lambda x: self._rewrite_url(x.strip()), values)
+        return ', '.join(values)
+
     def _rewrite_css(self, css_content):
         if css_content:
             return self.css_rewriter.rewrite(css_content)
@@ -165,13 +175,18 @@ class HTMLRewriterMixin(object):
 
             # special case: inline JS/event handler
             if ((attr_value and attr_value.startswith('javascript:'))
-                or attr_name.startswith('on')):
+                 or attr_name.startswith('on')):
                 attr_value = self._rewrite_script(attr_value)
 
             # special case: inline CSS/style attribute
             elif attr_name == 'style':
                 attr_value = self._rewrite_css(attr_value)
 
+            # special case: srcset list
+            elif attr_name == 'srcset':
+                rw_mod = handler.get(attr_name, '')
+                attr_value = self._rewrite_srcset(attr_value, rw_mod)
+
             # special case: disable crossorigin attr
             # as they may interfere with rewriting semantics
             elif attr_name == 'crossorigin':
@@ -181,7 +196,7 @@ class HTMLRewriterMixin(object):
             # don't rewrite rel=canonical
             elif tag == 'link' and attr_name == 'href':
                 if (self.opts.get('rewrite_rel_canon', True) or
-                    not self.has_attr(tag_attrs, ('rel', 'canonical'))):
+                     not self.has_attr(tag_attrs, ('rel', 'canonical'))):
                     rw_mod = handler.get(attr_name)
                     attr_value = self._rewrite_url(attr_value, rw_mod)
 
@@ -190,7 +205,13 @@ class HTMLRewriterMixin(object):
                 if self.has_attr(tag_attrs, ('http-equiv', 'refresh')):
                     attr_value = self._rewrite_meta_refresh(attr_value)
 
-            # special case: data- attrs
+            # special case: param value, conditional rewrite
+            elif (tag == 'param'):
+                if attr_value.startswith(self.DATA_RW_PROTOCOLS):
+                    rw_mod = handler.get(attr_name)
+                    attr_value = self._rewrite_url(attr_value, rw_mod)
+
+            # special case: data- attrs, conditional rewrite
             elif attr_name and attr_value and attr_name.startswith('data-'):
                 if attr_value.startswith(self.DATA_RW_PROTOCOLS):
                     rw_mod = 'oe_'
